@@ -11,7 +11,7 @@ from PIL import Image, ImageEnhance
 from disclosure_extractor.image_processing import clean_image
 from disclosure_extractor.image_processing import find_redactions
 
-sema = threading.Semaphore(value=20)
+sema = threading.Semaphore(value=10)
 
 
 def ocr_page(image: Image) -> str:
@@ -136,6 +136,11 @@ def ocr_slice(
     :param column_index: Column we are processing
     :return: text of cell.
     """
+    if field == "Addendum":
+        return pytesseract.image_to_string(
+            image_crop,
+            config="--psm 6 --oem 3 preserve_interword_spaces=1",
+        )
 
     cleaned_image = clean_image(image_crop)
     if cleaned_image.size == 0:
@@ -219,15 +224,28 @@ def process_addendum_normal(images, results):
     )
     results["Additional Information or Explanations"] = {
         "is_redacted": find_redactions(slice),
-        "text": ocr_slice(slice, 1, None),
+        "text": ocr_slice(slice, 1, "Addendum"),
     }
     return results
 
 
 def process_row(row, page, results, k, row_count):
+    """Process indivdual row data
+
+    :param row:
+    :param page:
+    :param results:
+    :param k:
+    :param row_count:
+    :return:
+    """
     sema.acquire()
     ocr_key = 1
+    pg_num = None
     for field, column in row.items():
+        if not pg_num:
+            page_number = int(column["page"]) + 1
+
         crop = page.crop(column["coords"])
         if column["section"] == "Liabilities":
             ocr_key += 1
@@ -243,17 +261,17 @@ def process_row(row, page, results, k, row_count):
         else:
             text = ocr_slice(crop, ocr_key, field, column["section"]).strip()
 
-        results["sections"][k]["rows"][row_count][field] = {}
+        data = {}
         if column["section"] == "Investments and Trusts":
-            results["sections"][k]["rows"][row_count][field][
-                "text"
-            ] = clean_stock_names(text)
+            data["text"] = clean_stock_names(text)
         else:
-            results["sections"][k]["rows"][row_count][field]["text"] = text
+            data["text"] = text
+
+        data["is_redacted"] = find_redactions(crop)
+        data["page_number"] = page_number
+
+        results["sections"][k]["rows"][row_count][field] = data
 
-        results["sections"][k]["rows"][row_count][field][
-            "is_redacted"
-        ] = find_redactions(crop)
     sema.release()
     return results
 
